@@ -57,7 +57,7 @@ def args(*params) -> Dict[int, Any]:
 class _CborDataObject(_DataClassMapping[int]):
     @classmethod
     def _get_field_key(cls, field: Field) -> int:
-        return fields(cls).index(field) + 1
+        return fields(cls).index(field) + 1  # type: ignore
 
 
 @dataclass(eq=False, frozen=True)
